@@ -4,9 +4,9 @@ import numpy as np
 from ..math_utils import rotateEuler
 
 try:
-    from Firefly.data_reader import Reader,ParticleGroup
+    from firefly.data_reader import Reader,ParticleGroup
 except (ModuleNotFoundError,ImportError):
-    print("Missing Firefly, obtain it at http://github.com/ageller/Firefly or pip install Firefly-vis.")
+    print("Missing firefly, obtain it at http://github.com/ageller/Firefly or pip install firefly.")
 
 
 from matplotlib.colors import to_rgba
@@ -19,14 +19,17 @@ colors = {
 
 class Firefly_helper(object):
 
-    def initialize_reader(self,JSONdir=None,write_startup='append',**kwargs):
+    def initialize_reader(self,JSONdir=None,write_startup='append',firefly_data_dir=None,**kwargs):
         """Kwargs passed to this function will create a new self.reader instance:\n"""
         
+        if firefly_data_dir is None: firefly_data_dir = os.path.join(self.datadir,'firefly')
+
         if JSONdir is None:
             JSONdir = os.path.join(
-                self.datadir,
-                'firefly',
+                firefly_data_dir,
                 '%s_%03d'%(self.name,self.snapnum))
+        if not os.path.isdir(os.path.dirname(JSONdir)):
+            os.makedirs(os.path.dirname(JSONdir))
 
         self.reader = Reader(JSONdir=JSONdir,clean_JSONdir=True,write_startup=write_startup,**kwargs)
         return self.reader
@@ -91,30 +94,34 @@ class Firefly_helper(object):
         if mask is not None:
             coords = coords[mask]
 
+        tracked_arrays = {}
+        for key in keys:
+
+            if key == 'Radius':
+                value = np.sqrt(np.sum(coords**2,axis=1))/self.rvir
+            else:
+                if key[:5] != 'log10':
+                    value = which_snap[key] 
+                else:
+                    value = np.log10(which_snap[key[5:]])
+
+                if mask is not None:
+                    value = value[mask]
+
+            tracked_arrays[key] = value
+
         this_ParticleGroup = self.track_firefly_particles(
             UIname,
             coords,
-            decimation_factor)
-
-        for key in keys:
-
-            if key[:5] != 'log10':
-                value = which_snap[key] 
-            else:
-                value = np.log10(which_snap[key[5:]])
-
-            if mask is not None:
-                value = value[mask]
-            this_ParticleGroup.trackArray(
-                key,
-                value)
+            decimation_factor,
+            tracked_arrays=tracked_arrays)
 
         ## start with velocity vectors enabled
-        self.reader.options['showVel'][UIname] = True
-        self.reader.options['velType'][UIname] = 'arrow'
+        self.reader.settings['showVel'][UIname] = True
+        self.reader.settings['velType'][UIname] = 'arrow'
 
         if color is None:
-            self.reader.options['color'][UIname] = colors[pname]
+            self.reader.settings['color'][UIname] = colors[pname]
         else:
             if len(color) != 4 and type(color) != list:
                 if type(color) == str:
@@ -124,9 +131,9 @@ class Firefly_helper(object):
                 else:
                     print(color,type(color))
                     raise ValueError('Color must be an RGBA list')
-            self.reader.options['color'][UIname] = color
+            self.reader.settings['color'][UIname] = color
 
-        self.reader.options['sizeMult'][UIname] = 5 if UIname != 'hot' else 8
+        self.reader.settings['sizeMult'][UIname] = 5 if UIname != 'hot' else 8
         
         return this_ParticleGroup 
 
@@ -141,10 +148,12 @@ class Firefly_helper(object):
         radius = 5*self.rstar_half if radius is None else radius
         height = 10 if height is None else height
 
-        disk_coords = np.zeros((180,3))
-        thetas = np.linspace(0,2*np.pi,disk_coords.shape[0],endpoint=False)
-        disk_coords[:,0] = radius*self.rstar_half*np.cos(thetas)
-        disk_coords[:,1] = radius*self.rstar_half*np.sin(thetas)
+        n_repeat = 5
+        disk_coords = np.zeros((360*n_repeat,3))
+        thetas = np.linspace(0,2*np.pi,int(disk_coords.shape[0]/n_repeat),endpoint=False)
+        disk_coords[:,0] = np.tile(radius*np.cos(thetas),n_repeat)
+        disk_coords[:,1] = np.tile(radius*np.sin(thetas),n_repeat)
+        disk_coords[:,2] = np.repeat(np.linspace(-1,1,n_repeat),360)*height
 
         zaxis_coords = np.zeros((20,3))
         zaxis_coords[:,-1] = np.linspace(-height,height,20,endpoint=True)
@@ -163,25 +172,23 @@ class Firefly_helper(object):
             if reorient_angles is not None:
                 key+='_orient'
 
-            self.track_firefly_particles(
-                key,
-                coords,
-                1)
+            self.track_firefly_particles(key,coords,1)
 
-            self.reader.options['UIparticle'][key] = False 
-            self.reader.options['color'][key] = [1.0,1.0,1.0,1.0]
-            self.reader.options['sizeMult'][key] = 2.5
+            self.reader.settings['UIparticle'][key] = False 
+            self.reader.settings['color'][key] = [1.0,1.0,1.0,1.0]
+            self.reader.settings['sizeMult'][key] = 2.5
                 
     def track_firefly_particles(
         self,
         UIname,
         coords,
-        decimation_factor = 1
-        ):
+        decimation_factor=1,
+        **kwargs):
 
         self.reader.addParticleGroup(ParticleGroup(
             UIname,
             coords,
-            decimation_factor=decimation_factor))
+            decimation_factor=decimation_factor,
+            **kwargs))
 
         return self.reader.particleGroups[-1]
