@@ -17,6 +17,7 @@ from .movie_utils import Draw_helper,FIREstudio_helper
 from .sfr_utils import SFR_helper
 from .metadata_utils import metadata_cache,Metadata,MultiMetadata
 from .firefly_utils import Firefly_helper
+from .scale_height_utils import ScaleHeight_helper
 
 ## mapping between particle type and what I called them
 sub_snap_dict = {
@@ -43,6 +44,25 @@ elvis_partners = {
     'Thelma':('Louise',0),
     'Louise':('Thelma',1)}
 
+
+cr_heating_fixed = [
+    'm09_res30',
+    'm09_res250',
+    'm10q_res30',
+    'm10q_res250',
+    'm10v_res30 ',
+    'm10v_res250',
+    'm11b_res2100_no-swb',
+    'm11b_res2100_no-swb_v2 ',
+    'm11b_res2100',
+    'm11b_res2100_no-swb_contaminated',
+    'm11e_res7100',
+    'm12i_res7100',
+    'm12i_res57000',
+    'm12f_res7100',
+    'm12s_res113000',
+    'm12w_res57000']
+
 def get_elvis_snapdir_name(savename):
 
     this_name = None
@@ -79,7 +99,8 @@ class Galaxy(
     Firefly_helper,
     Draw_helper,
     FIREstudio_helper,
-    SFR_helper):
+    SFR_helper,
+    ScaleHeight_helper):
     """------- Galaxy
         Input:
             name - name of the simulation directory
@@ -101,7 +122,9 @@ class Galaxy(
     __doc__+= (
         "\n"+Draw_helper.__doc__ + 
         "\n"+FIREstudio_helper.__doc__ +
-        "\n"+SFR_helper.__doc__)
+        "\n"+SFR_helper.__doc__+
+        "\n"+ScaleHeight_helper.__doc__)
+
 
     def hasattr(self,attr):
         return attr in dir(self)
@@ -135,7 +158,7 @@ class Galaxy(
         ahf_fname = None,
         save_header_to_table = True,
         meta_name = None,
-        suite_name = 'cr_heating_fix',
+        suite_name = 'metal_diffusion',
         **metadata_kwargs 
         ):
 
@@ -155,13 +178,19 @@ class Galaxy(
                 #self.suite_name = 'unknown'
         #else:
 
+
+        if suite_name == 'metal_diffusion' and name in cr_heating_fixed:
+            suite_name = 'metal_diffusion/cr_heating_fix'
+
         self.suite_name = suite_name
 
-        if self.suite_name == 'cr_heating_fix':
-            self.suite_name = 'metal_diffusion/cr_heating_fix'
-
-        if self.suite_name == 'cr_suite' and name == 'm12i_res7100':
-            name = 'm12i_mass7000_MHDCR_tkFIX/cr_700'
+        if self.suite_name == 'cr_suite':
+            if name == 'm12i_res7100':
+                name = 'm12i_mass7000_MHDCR_tkFIX/cr_700'
+            else:
+                name +='/cr_700'
+            name=name.replace('cr_700/cr_700','cr_700')
+            
 
         ## bind input
         self.snapnum = snapnum
@@ -175,6 +204,12 @@ class Galaxy(
             name,
             'output')
 
+        if snapdir is not None:
+            ## will replace name with name if not an elvis name
+            ##  otherwise will replace Romeo_res3500 w/ RomeoJuliet_res3500
+            ##  or Juliet_res3500 w/ RomeoJuliet_res3500
+            snapdir = snapdir.replace(name,get_elvis_snapdir_name(name))
+
         ## snapdir is sometimes None if an instance is 
         ##  created just to access the metadata and cached
         ##  methods
@@ -319,6 +354,10 @@ class Galaxy(
             self.rvir = 300 ## what should i do here...
             self.rstar_half = None
 
+            if 'r30r' in self.snapdir:
+                self.scom = get_idealized_center(self.name,self.snapnum)
+
+
         ## have we already calculated it and cached it?
         if self.rstar_half is None:
             for attr in ['gas_extract_rstar_half','star_extract_rstar_half']:
@@ -345,7 +384,8 @@ class Galaxy(
                 if 'elvis' in self.snapdir:
                     raise IOError("No AHF files for Elvis runs")
                 self.load_ahf(ahf_fname=halo_fname,ahf_path=halo_path)
-            except IOError:
+            except IOError as e:
+                #print(e)
                 try:
                     
                     if 'elvis' in self.snapdir:
@@ -441,6 +481,25 @@ class Galaxy(
                     raise IOError("can't find a halo file (or found too many)",fnames)
 
         return ahf_path, ahf_fname
+    
+    def get_ahf_file_output(self):
+        try: return load_AHF(
+                self.snapdir,
+                self.snapnum,
+                self.current_redshift,
+                ahf_path = self.ahf_path,
+                fname = self.ahf_fname,
+                hubble = self.header['HubbleParam'],
+                return_full_halo_file=True).T
+        except: return load_AHF(
+                self.snapdir,
+                self.snapnum,
+                self.current_redshift,
+                ahf_path = self.ahf_path,
+                fname = self.ahf_fname,
+                hubble = self.header['HubbleParam'],
+                return_full_halo_file=True,
+                extra_names_to_read=[]).T
 
     def load_rockstar(self,rockstar_fname=None,rockstar_path=None,which_host=0):
 
@@ -640,10 +699,9 @@ class Galaxy(
 
                 ## manually calcualte rstar half using the star particles
                 ##  rather than relying on the output of AHF
-                if self.rstar_half is None:
-                    self.load_stars()
-                    self.rstar_half = self.calculate_half_mass_radius() 
-
+                if self.rstar_half is None: self.get_rstar_half(
+                    save_meta=save_meta,
+                    force_from_file=True)
 
                 ## radius to calculate angular momentum
                 ##  to orient on 
@@ -684,7 +742,8 @@ class Galaxy(
             ##  them from disk
             else:
                 try:
-                    assert use_saved_subsnapshots
+                    if not use_saved_subsnapshots: raise AssertionError("Told not to use saved sub-snapshots")
+
                     print("Using the saved sub-snapshots for",self)
 
                     self.sub_snap = openSnapshot(
@@ -706,7 +765,7 @@ class Galaxy(
                         abg_subsnap=1)
 
                     ## check if the extraction radius is what we want, to 4 decimal places
-                    if np.round(radius,4) != np.round(self.sub_snap['scale_radius'],4):
+                    if not np.isclose(np.round(radius,4),np.round(self.sub_snap['scale_radius'],4)):
                         this_sim = self.snapdir.split('snaps')[1].split('/output')[0]
                         if this_sim not in fname:
                             raise ValueError("%s %s do not correspond"%(self.snapdir,fname))
@@ -719,12 +778,12 @@ class Galaxy(
                         del self.sub_dark_snap
                         already_saved = False
 
-                        raise ValueError("scale_radius is not the same",
+                        raise ValueError("virial radius is not the same",
                             radius-sub_scale_radius,
                             radius,sub_scale_radius)
 
                     ## check if halo center is the same to 4 decimal places
-                    if (np.round(self.scom,4) != np.round(self.sub_snap['scom'],4)).any():
+                    if not np.isclose(np.round(self.scom,4),np.round(self.sub_snap['scom'],4)).all():
                         this_sim = self.snapdir.split('snaps')[1].split('/output')[0]
                         if this_sim not in fname:
                             raise ValueError("%s %s do not correspond"%(self.snapdir,fname))
@@ -839,8 +898,29 @@ class Galaxy(
 
         return return_value
 
+    def get_rstar_half(self,
+        use_metadata=True,
+        save_meta=False,
+        loud=True,
+        assert_cached=False,
+        force_from_file=False,
+        **kwargs):
+    
+        @metadata_cache(
+            'star_extract',
+            ['rstar_half'],
+            use_metadata=use_metadata,
+            save_meta=save_meta,
+            loud=loud,
+            assert_cached=assert_cached,
+            force_from_file=force_from_file)
+        def compute_rstar_half(self):
+            self.load_stars()
+            return self.calculate_half_mass_radius(),
+        return compute_rstar_half(self)
+
     def load_stars(self,**kwargs):
-        print("Loading star particles of",self)
+        print("Loading star particles of",self,'at',self.snapdir)
         if not hasattr(self,'star_snap'):
             self.star_snap = openSnapshot(
                 self.snapdir,
@@ -848,107 +928,18 @@ class Galaxy(
                 **kwargs)
 
     def load_gas(self,**kwargs):
-        print("Loading gas particles of",self)
+        print("Loading gas particles of",self,'at',self.snapdir)
         self.snap = openSnapshot(
             self.snapdir,
             self.snapnum,0,
             **kwargs)
 
     def load_dark_matter(self,**kwargs):
-        print("Loading dark matter particles of",self)
+        print("Loading dark matter particles of",self,'at',self.snapdir)
         self.dark_snap = openSnapshot(
             self.snapdir,self.snapnum,1,
             **kwargs)
 
-    def calculate_half_mass_radius(
-        self,
-        which_snap=None,
-        geometry='spherical',
-        within_radius=None):
-
-        within_radius = self.rvir if within_radius is None else within_radius
-
-        ## find the stars within the virial radius
-        if which_snap is None:
-            which_snap = self.star_snap
-
-        if 'overwritten' in which_snap.keys() and which_snap['overwritten']:
-            coords = which_snap['Coordinates']
-        else:
-            coords = which_snap['Coordinates']-self.scom
-
-        masses = which_snap['Masses']
-
-        edges = np.linspace(0,within_radius,5000,endpoint=True)
-
-        if geometry in ['cylindrical','scale_height']:
-            radii = np.sum(coords[:,:2]**2,axis=1)**0.5
-        elif geometry == 'spherical':
-            print("Calculating the half mass radius")
-            radii = np.sum(coords**2,axis=1)**0.5
-
-        within_mask = radii <= within_radius
-
-        ## let's co-opt this method to calculate a scale height as well
-        if geometry == 'scale_height':
-            ## take the z-component
-            radii = np.abs(coords[:,-1])
-            edges = np.linspace(0,10*within_radius,5000,endpoint=True)
-
-        h,edges = np.histogram(
-            radii[within_mask],
-            bins=edges,
-            weights = masses[within_mask])
-
-        h/=1.0*np.sum(h)
-        cdf = np.cumsum(h)
-
-        return findIntersection(edges[1:],cdf,0.5)[0]
-    
-    def get_simple_radius_and_height(
-        self,
-        component='gas',
-        save_meta=True,
-        use_metadata=True,
-        loud=True,
-        **kwargs):
-
-        if component not in ['gas','stars']:
-            raise ValueError("Invalid component %s must be gas or star."%component)
-
-        group_name = 'SimpleGeom_%s'%component
-
-        @metadata_cache(
-            group_name,
-            ['%s_simple_r'%component,
-            '%s_simple_h'%component],
-            use_metadata=use_metadata,
-            save_meta=save_meta,
-            loud=loud)
-        def compute_simple_radius_and_height(self,component):
-
-            if component == 'gas':
-                which_snap = self.sub_snap
-            elif component == 'stars':
-                which_snap = self.sub_star_snap
-
-            ## calculate the cylindrical half-mass radius using mass 
-            ##  within 20% virial radius
-            radius = self.calculate_half_mass_radius(
-                which_snap=which_snap,
-                geometry='cylindrical',
-                within_radius=0.2*self.rvir)
-
-            ## calculate the half-mass height w/i cylinder
-            ##  of radius previously calculated
-            height = self.calculate_half_mass_radius(
-                which_snap=which_snap,
-                geometry='scale_height',
-                within_radius=radius)
-                
-            return radius,height
-        return compute_simple_radius_and_height(self,component,**kwargs)
-
     ## load and save things to object
     def outputSubsnapshot(
         self,
@@ -1193,19 +1184,23 @@ class ManyGalaxy(Galaxy):
         load_snapnums=None,
         population_kwargs=None,
         name_append='',
-        suite_name='cr_heating_fix',
+        suite_name='metal_diffusion',
         **galaxy_kwargs):
         """ a wrapper that will allow one to open multiple galaxies at the same time,
             most useful for creating and accessing MultiMetadata instances while 
             using the same plotting scripts that a Galaxy instance would work for 
             (in general, this must be done consciously while making a plotting script). """
 
-
-        if suite_name == 'cr_heating_fix':
+        if suite_name == 'metal_diffusion' and name in cr_heating_fixed:
             suite_name = 'metal_diffusion/cr_heating_fix'
+ 
 
-        if suite_name == 'cr_suite' and name == 'm12i_res7100':
-            name = 'm12i_mass7000_MHDCR_tkFIX/cr_700'
+        if suite_name == 'cr_suite':
+            if name == 'm12i_res7100':
+                name = 'm12i_mass7000_MHDCR_tkFIX/cr_700'
+            else:
+                name +='/cr_700'
+            name=name.replace('cr_700/cr_700','cr_700')
 
         self.name = name+name_append
         self.datadir_name = self.name if datadir_name is None else datadir_name
@@ -1386,3 +1381,23 @@ class ManyGalaxy(Galaxy):
         new_kwargs.update(kwargs)
 
         return Galaxy(self.name,snapnum,**new_kwargs)
+
+def get_idealized_center(savename,snapnum):
+
+    center_name = {
+        'm11_def_r30r':'centers_feedback_normal',
+        'm11_light_def_r30r':'centers_feedback_light',
+        'm11_extralight_def_r30r':'centers_feedback_extralight',
+    }[savename]
+
+    center_path = os.path.join(
+        os.environ['HOME'],
+        'scratch',
+        'data',
+        'jonathan_centers',
+        center_name+'.npz')
+
+    try:
+        return np.load(center_path)['centers'][snapnum]
+    except:
+        return np.load(center_path)['centers'][snapnum-1]
\ No newline at end of file
