@@ -35,6 +35,7 @@ except:
 
 ## stupid way of handling black faceolor... 
 GLOBAL_linecolor='k'
+GLOBAL_lw=1.5
 
 def add_many_to_legend(
     ax,
@@ -88,13 +89,15 @@ def add_to_legend(
     shape='line',
     loc=0,
     ls='-',
-    c='k',
+    c=None,
     alpha=1,
     lw=None,
     legend_kwargs=None,
     make_new_legend=False,
     **kwargs):
 
+    if c is None: c = GLOBAL_linecolor 
+
     legend = ax.get_legend()
     ## add the current legend to the tracked artists
     ##  and then pretend we weren't passed one
@@ -122,8 +125,8 @@ def add_to_legend(
             ax.markers = []
         line_kwargs = {}
 
-        if lw is not None:
-            line_kwargs['lw'] = lw
+        if lw is not None: line_kwargs['lw'] = lw
+        else: line_kwargs['lw'] = GLOBAL_lw
 
         line = Line2D(
         [0],[0],
